@@ -20,7 +20,7 @@ LoadToolButton::LoadToolButton(QWidget *parent)
     auto mainMenu = new QMenu(this);
     setMenu(mainMenu);
 
-    QAction *act = mainMenu->addAction(i18n("Load From File…"));
+    QAction *act = mainMenu->addAction(i18nc("@action", "Load From File…"));
     connect(act, &QAction::triggered, this, &LoadToolButton::loadFromFile);
 
     mLoadMenu->setObjectName("loadMenu"_L1);
